FileSystemFailure class

The operation failed for a reason the browser reported.

Inheritance

Constructors

FileSystemFailure(String message)
Creates the exception.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
What went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited