PermissionDeniedException class
The page does not have permission to read or write the handle.
- Inheritance
-
- Object
- FileSystemAccessException
- PermissionDeniedException
Constructors
- PermissionDeniedException(String message)
-
Creates the exception.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited